@@ -2,10 +2,9 @@
 
 #![allow(clippy::module_name_repetitions)]
 
-use iced::widget::rule::{Catalog, FillMode, Style};
-use iced::Color;
-
 use crate::StyleType;
+use iced::Color;
+use iced::widget::rule::{Catalog, FillMode, Style};
 
 #[derive(Default)]
 pub enum RuleType {
@@ -14,6 +13,8 @@ pub enum RuleType {
     PaletteColor(Color, u16),
     Incoming,
     Outgoing,
+    FilteredOut,
+    Dropped,
 }
 
 impl RuleType {
@@ -25,15 +26,17 @@ impl RuleType {
                 RuleType::Incoming => colors.secondary,
                 RuleType::Outgoing => colors.outgoing,
                 RuleType::PaletteColor(color, _) => *color,
+                RuleType::Dropped => ext.red_alert_color,
+                RuleType::FilteredOut => ext.buttons_color,
                 RuleType::Standard => Color {
                     a: ext.alpha_round_borders,
                     ..ext.buttons_color
                 },
             },
             width: match self {
-                RuleType::Incoming | RuleType::Outgoing => 5,
                 RuleType::PaletteColor(_, width) => *width,
                 RuleType::Standard => 3,
+                _ => 5,
             },
             radius: 0.0.into(),
             fill_mode: FillMode::Full,
