@@ -1,5 +1,7 @@
 pub mod address_port_pair;
+pub mod arp_type;
 pub mod asn;
+pub mod bogon;
 pub mod byte_multiple;
 pub mod capture_context;
 pub mod data_info;
