@@ -1,15 +1,16 @@
 use std::fmt;
 use std::thread;
 
+use iced::Font;
 use iced::widget::Text;
-use iced::{Alignment, Font, Length};
 use rodio::{Decoder, OutputStream, Sink};
 use serde::{Deserialize, Serialize};
 
 use crate::gui::styles::style_constants::FONT_SIZE_FOOTER;
 use crate::notifications::types::sound::Sound::{Gulp, Pop, Swhoosh};
+use crate::utils::error_logger::{ErrorLogger, Location};
 use crate::utils::types::icon::Icon;
-use crate::StyleType;
+use crate::{StyleType, location};
 
 /// Enum representing the possible notification sounds.
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Serialize, Deserialize)]
@@ -50,27 +51,31 @@ impl Sound {
             Sound::None => Icon::Forbidden.to_text(),
         }
         .size(FONT_SIZE_FOOTER)
-        .width(Length::Fill)
-        .align_x(Alignment::Center)
-        .align_y(Alignment::Center)
     }
 }
 
 pub fn play(sound: Sound, volume: u8) {
-    if sound.eq(&Sound::None) || volume == 0 {
+    if sound.eq(&Sound::None) || volume == 0 || cfg!(test) {
         return;
     }
     let mp3_sound = sound.mp3_sound();
-    thread::Builder::new()
+    let _ = thread::Builder::new()
         .name("thread_play_sound".to_string())
         .spawn(move || {
-            // Get a output stream handle to the default physical sound device
-            let (_stream, stream_handle) = OutputStream::try_default().unwrap();
-            let sink = Sink::try_new(&stream_handle).unwrap();
+            // Get an output stream handle to the default physical sound device
+            let Ok((_stream, stream_handle)) = OutputStream::try_default().log_err(location!())
+            else {
+                return;
+            };
+            let Ok(sink) = Sink::try_new(&stream_handle).log_err(location!()) else {
+                return;
+            };
             //load data
             let data = std::io::Cursor::new(mp3_sound);
             // Decode that sound file into a source
-            let source = Decoder::new(data).unwrap();
+            let Ok(source) = Decoder::new(data).log_err(location!()) else {
+                return;
+            };
             // Play the sound directly on the device
             sink.set_volume(f32::from(volume) / 200.0); // set the desired volume
             sink.append(source);
@@ -78,5 +83,5 @@ pub fn play(sound: Sound, volume: u8) {
             // has finished playing all its queued sounds.
             sink.sleep_until_end();
         })
-        .unwrap();
+        .log_err(location!());
 }
