@@ -16,6 +16,7 @@ pub fn new_version_available_translation(language: Language) -> &'static str {
         Language::ES => "Hay una nueva versión disponible!",
         Language::KO => "새로운 버전이 출시되었습니다!",
         Language::ZH => "新版本已在 Github 发布!",
+        Language::ZH_TW => "有可用的新版本！",
         Language::UK => "Нова версія доступна!",
         Language::RO => "O versiune nouă este disponibilă!",
         Language::PL => "Nowsza wersja jest dostępna!",
@@ -24,6 +25,7 @@ pub fn new_version_available_translation(language: Language) -> &'static str {
         Language::UZ => "Yangi versiya mavjud!",
         Language::PT => "Uma nova versão está disponível!",
         Language::VI => "Phiên bản mới đã sẵn sàng!",
+        Language::ID => "Versi baru tersedia!",
     }
 }
 
@@ -42,12 +44,14 @@ pub fn inspect_translation(language: Language) -> &'static str {
         // Language::FA => "بازرسی",
         Language::KO => "검사",
         Language::ZH => "检查",
-        Language::UK => "Інспектувати",
+        Language::ZH_TW => "檢查",
+        Language::UK => "Перевірити",
         Language::RO => "Inspectați",
         Language::JA => "検査",
         Language::UZ => "Tekshirish",
         Language::PT => "Inspecionar",
         Language::VI => "Quan sát",
+        Language::ID => "Memeriksa",
         _ => "Inspect",
     }
 }
@@ -65,6 +69,7 @@ pub fn connection_details_translation(language: Language) -> &'static str {
         Language::ES => "Detalles de la conexión",
         Language::KO => "연결 상세",
         Language::ZH => "连接详情",
+        Language::ZH_TW => "連線詳細資訊",
         Language::UK => "Деталі зʼєднання",
         Language::RO => "Detalii conexiune",
         Language::PL => "Szczegóły połączenia",
@@ -73,32 +78,35 @@ pub fn connection_details_translation(language: Language) -> &'static str {
         Language::UZ => "Ulanish tafsilotlari",
         Language::PT => "Detalhes da conexão",
         Language::VI => "Thông tin kết nối",
+        Language::ID => "Rincian koneksi",
         _ => "Connection details",
     }
 }
 
-pub fn dropped_packets_translation(language: Language) -> &'static str {
+// refers to bytes or packets dropped because they weren't processed fast enough
+pub fn dropped_translation(language: Language) -> &'static str {
     match language {
-        Language::EN => "Dropped packets",
-        Language::IT => "Pacchetti mancati",
-        Language::RU => "Потеряно пакетов",
-        Language::SV => "Tappade paket",
-        Language::FI => "Pudotetut paketit",
-        Language::DE => "Verlorene Pakete",
-        Language::TR => "Düşen paketler",
-        // Language::FA => "بسته های رها شده",
-        Language::ES => "Paquetes perdidos",
-        Language::KO => "손실 패킷",
-        Language::ZH => "丢包计数",
-        Language::UK => "Пропущені пакети",
-        Language::RO => "Pachete pierdute",
-        Language::PL => "Utracone pakiety",
-        Language::FR => "Packets perdus",
-        Language::JA => "ドロップしたパケット",
-        Language::UZ => "Yig'ilgan paketlar",
-        Language::PT => "Pacotes perdidos",
-        Language::VI => "Gói tin đã bị mất",
-        _ => "Dropped packets",
+        Language::EN => "Dropped",
+        Language::IT => "Persi",
+        Language::RU => "Потеряно",
+        Language::SV => "Tappade",
+        Language::FI => "Pudotetut",
+        Language::DE => "Verlorene",
+        Language::TR => "Düşen",
+        // Language::FA => "رها شده",
+        Language::ES | Language::PT => "Perdidos",
+        Language::KO => "손실",
+        Language::ZH => "丢计",
+        Language::ZH_TW => "丟棄",
+        Language::UK => "Пропущені",
+        Language::RO => "Pierdute",
+        Language::PL => "Utracone",
+        Language::FR => "Perdus",
+        Language::JA => "ドロップした",
+        Language::UZ => "Yig'ilgan",
+        Language::VI => "Mất",
+        Language::ID => "Dihapus",
+        _ => "Dropped",
     }
 }
 
@@ -115,7 +123,8 @@ pub fn data_representation_translation(language: Language) -> &'static str {
         Language::ES => "Representación de los datos",
         Language::KO => "데이터 단위",
         Language::ZH => "图表数据",
-        Language::UK => "Представлення даних",
+        Language::ZH_TW => "資料呈現方式",
+        Language::UK => "Відображення даних",
         Language::RO => "Reprezentarea datelor",
         Language::PL => "Reprezentacja danych",
         Language::FR => "Représentation de données",
@@ -123,6 +132,7 @@ pub fn data_representation_translation(language: Language) -> &'static str {
         Language::UZ => "Ma'lumotlarni taqdim etish",
         Language::PT => "Representação dos dados",
         Language::VI => "Miêu tả dữ liệu",
+        Language::ID => "Penyajian ulang data",
         _ => "Data representation",
     }
 }
@@ -140,6 +150,7 @@ pub fn host_translation(language: Language) -> &'static str {
         Language::ES => "Host de red",
         Language::KO => "네트워크 호스트",
         Language::ZH => "主机",
+        Language::ZH_TW => "網路主機",
         Language::UK => "Мережевий хост",
         Language::RO => "Host rețea",
         Language::PL => "Host sieciowy",
@@ -148,6 +159,7 @@ pub fn host_translation(language: Language) -> &'static str {
         Language::UZ => "Tarmoq serveri",
         Language::PT => "Host da rede",
         Language::VI => "Máy chủ",
+        Language::ID => "Jaringan asal",
         _ => "Network host",
     }
 }
@@ -165,7 +177,8 @@ pub fn only_top_30_items_translation(language: Language) -> &'static str {
         Language::ES => "Aquí sólo se muestran los 30 primeros elementos",
         Language::KO => "상위 30개의 아이템만 노출됩니다",
         Language::ZH => "仅展示前 30 个项目",
-        Language::UK => "Лише верхні 30 елементи відображаються тут",
+        Language::ZH_TW => "此處僅顯示前 30 個項目",
+        Language::UK => "Тут відображаються лише перші 30 елементів",
         Language::RO => "Doar primele 30 de articole sunt afișate aici",
         Language::PL => "Tylko 30 pierwszych rzeczy jest wyświetlanych",
         Language::FR => "Seuls les 30 premiers articles sont affichés ici",
@@ -173,6 +186,7 @@ pub fn only_top_30_items_translation(language: Language) -> &'static str {
         Language::UZ => "Bu erda faqat dastlabki 30 ta buyumlar ko'rsatiladi",
         Language::PT => "Apenas os 30 melhores unid são expostos aqui",
         Language::VI => "Chỉ có 30 mục gần nhất được hiển thị ở đây",
+        Language::ID => "Hanya 30 teratas yang ditampilkan disini",
         _ => "Only the top 30 items are displayed here",
     }
 }
@@ -190,12 +204,14 @@ pub fn only_top_30_items_translation(language: Language) -> &'static str {
 //         Language::ES | Language::PT => "Ordenar por",
 //         Language::KO => "정렬",
 //         Language::ZH => "排序",
+//         Language::ZH_TW => "排序依據",
 //         Language::UK => "Сортувати за",
 //         Language::RO => "Filtrează după",
 //         Language::PL => "Sortuj według",
 //         Language::FR => "Trier par",
 //         Language::JA => "ソート",
 //         Language::UZ => "Saralash turi",
+//         Language::ID => "Urut berdasarkan",
 //         _ => "Sort by",
 //     }
 // }
@@ -213,6 +229,7 @@ pub fn local_translation(language: Language) -> &'static str {
         Language::ES => "Red local",
         Language::KO => "로컬 네트워크",
         Language::ZH => "局域网",
+        Language::ZH_TW => "區域網路",
         Language::UK => "Локальна мережа",
         Language::RO => "Rețea locală",
         Language::PL => "Sieć lokalna",
@@ -221,6 +238,7 @@ pub fn local_translation(language: Language) -> &'static str {
         Language::UZ => "Mahalliy tarmoq",
         Language::PT => "Rede local",
         Language::VI => "Mạng nội bộ",
+        Language::ID => "Jaringan lokal",
         _ => "Local network",
     }
 }
@@ -238,7 +256,8 @@ pub fn unknown_translation(language: Language) -> &'static str {
         Language::ES => "Ubicación desconocida",
         Language::KO => "알 수 없는 위치",
         Language::ZH => "未知",
-        Language::UK => "Невідома локація",
+        Language::ZH_TW => "未知位置",
+        Language::UK => "Невідоме місцезнаходження",
         Language::RO => "Locație necunoscută",
         Language::PL => "Nieznana lokalizacja",
         Language::FR => "Localisation inconnue",
@@ -246,6 +265,7 @@ pub fn unknown_translation(language: Language) -> &'static str {
         Language::UZ => "Noma'lum joylashuv",
         Language::PT => "Localização desconhecida",
         Language::VI => "Không rõ địa điểm",
+        Language::ID => "Lokasi tidak diketahui",
         _ => "Unknown location",
     }
 }
@@ -263,6 +283,7 @@ pub fn your_network_adapter_translation(language: Language) -> &'static str {
         Language::ES => "Su adaptador de red",
         Language::KO => "네트워크 어댑터",
         Language::ZH => "你的网络适配器",
+        Language::ZH_TW => "您的網路介面卡",
         Language::UK => "Ваш мережевий адаптер",
         Language::RO => "Adaptorul dvs. de rețea",
         Language::PL => "Twój adapter sieciowy",
@@ -271,6 +292,7 @@ pub fn your_network_adapter_translation(language: Language) -> &'static str {
         Language::UZ => "Sizning tarmoq adapteringiz",
         Language::PT => "Seu adaptador de rede",
         Language::VI => "Network adapter của bạn",
+        Language::ID => "Adaptor jaringan kamu",
         _ => "Your network adapter",
     }
 }
@@ -288,6 +310,7 @@ pub fn socket_address_translation(language: Language) -> &'static str {
         Language::ES => "Dirección del socket",
         Language::KO => "소켓 어드레스",
         Language::ZH => "套接字地址",
+        Language::ZH_TW => "Socket 位址",
         Language::UK => "Адреса сокета",
         Language::RO => "Adresa socket-ului",
         Language::PL => "Adres gniazda",
@@ -296,6 +319,7 @@ pub fn socket_address_translation(language: Language) -> &'static str {
         Language::UZ => "Soket manzili",
         Language::PT => "Endereço da socket",
         Language::VI => "Địa chỉ socket",
+        Language::ID => "Alamat sambungan",
         _ => "Socket address",
     }
 }
@@ -313,6 +337,7 @@ pub fn mac_address_translation(language: Language) -> &'static str {
         Language::ES => "Dirección MAC",
         Language::KO => "맥 어드레스",
         Language::ZH => "MAC 地址",
+        Language::ZH_TW => "MAC 位址",
         Language::UK => "MAC-адреса",
         Language::RO => "Adresa MAC",
         Language::PL => "Adres MAC",
@@ -321,6 +346,7 @@ pub fn mac_address_translation(language: Language) -> &'static str {
         Language::UZ => "MAC manzili",
         Language::PT => "Endereço MAC",
         Language::VI => "Địa chỉ MAC",
+        Language::ID => "Alamat MAC",
         _ => "MAC address",
     }
 }
@@ -338,6 +364,7 @@ pub fn source_translation(language: Language) -> &'static str {
         Language::ES => "Origen",
         Language::KO => "소스",
         Language::ZH => "源",
+        Language::ZH_TW => "來源",
         Language::UK => "Джерело",
         Language::RO => "Sursă",
         Language::PL => "Źródło",
@@ -346,6 +373,7 @@ pub fn source_translation(language: Language) -> &'static str {
         Language::UZ => "Manba",
         Language::PT => "Fonte",
         Language::VI => "Nguồn",
+        Language::ID => "Asal",
         _ => "Source",
     }
 }
@@ -362,6 +390,7 @@ pub fn destination_translation(language: Language) -> &'static str {
         Language::ES | Language::PT => "Destino",
         Language::KO => "목적지",
         Language::ZH => "目标",
+        Language::ZH_TW => "目的地",
         Language::UK => "Призначення",
         Language::RO => "Destinație",
         Language::PL => "Miejsce docelowe",
@@ -369,6 +398,7 @@ pub fn destination_translation(language: Language) -> &'static str {
         Language::JA => "送信先",
         Language::UZ => "Qabul qiluvchi",
         Language::VI => "Đích",
+        Language::ID => "Tujuan",
         _ => "Destination",
     }
 }
@@ -386,6 +416,7 @@ pub fn fqdn_translation(language: Language) -> &'static str {
         Language::ES => "Nombre de dominio completo",
         Language::KO => "절대 도메인 네임",
         Language::ZH | Language::JA => "FQDN",
+        Language::ZH_TW => "FQDN",
         Language::UK => "Повністю визначене доменне ім'я",
         Language::RO => "Nume de domeniu complet calificat",
         Language::PL => "Pełna nazwa domeny",
@@ -393,6 +424,7 @@ pub fn fqdn_translation(language: Language) -> &'static str {
         Language::UZ => "To'liq domen nomi",
         Language::PT => "Nome de domínio completo",
         Language::VI => "Tên miền đầy đủ",
+        Language::ID => "Nama domain yang memenuhi syarat",
         _ => "Fully qualified domain name",
     }
 }
@@ -410,6 +442,7 @@ pub fn administrative_entity_translation(language: Language) -> &'static str {
         Language::ES => "Nombre del sistema autónomo",
         Language::KO => "관리 엔티티",
         Language::ZH => "ASN 信息",
+        Language::ZH_TW => "ASN 資訊",
         Language::UK => "Адміністративна одиниця",
         Language::RO => "Numele sistemului autonom",
         Language::PL => "Nazwa autonomicznego systemu",
@@ -418,6 +451,7 @@ pub fn administrative_entity_translation(language: Language) -> &'static str {
         Language::UZ => "Avtonom tizim nomi",
         Language::PT => "Entidade administrativa",
         Language::VI => "Tên Autonomous System",
+        Language::ID => "Nama System Otomatis",
         _ => "Autonomous System name",
     }
 }
@@ -435,6 +469,7 @@ pub fn transmitted_data_translation(language: Language) -> &'static str {
         Language::ES => "Datos transmitidos",
         Language::KO => "수신된 데이터",
         Language::ZH => "数据传输",
+        Language::ZH_TW => "已傳輸的資料",
         Language::UK => "Передані дані",
         Language::RO => "Date transmise",
         Language::PL => "Przesłane dane",
@@ -443,6 +478,7 @@ pub fn transmitted_data_translation(language: Language) -> &'static str {
         Language::UZ => "Uzatilgan ma'lumotlar",
         Language::PT => "Dados transmitidos",
         Language::VI => "Dữ liệu được truyền",
+        Language::ID => "Data terkirim",
         _ => "Transmitted data",
     }
 }
@@ -460,6 +496,7 @@ pub fn country_translation(language: Language) -> &'static str {
         Language::ES | Language::PT => "País",
         Language::KO => "국가",
         Language::ZH => "国家",
+        Language::ZH_TW => "國家",
         Language::UK => "Країна",
         Language::RO => "Țară",
         Language::PL => "Kraj",
@@ -467,6 +504,7 @@ pub fn country_translation(language: Language) -> &'static str {
         Language::JA => "国",
         Language::UZ => "Davlat",
         Language::VI => "Quốc gia",
+        Language::ID => "Negara",
         _ => "Country",
     }
 }
@@ -484,6 +522,7 @@ pub fn domain_name_translation(language: Language) -> &'static str {
         Language::ES => "Nombre de dominio",
         Language::KO => "도메인 네임",
         Language::ZH => "域名",
+        Language::ZH_TW => "網域名稱",
         Language::UK => "Доменне ім'я",
         Language::RO => "Nume domeniu",
         Language::PL => "Nazwa domeny",
@@ -492,6 +531,7 @@ pub fn domain_name_translation(language: Language) -> &'static str {
         Language::UZ => "Domen nomi",
         Language::PT => "Nome do domínio",
         Language::VI => "Tên miền",
+        Language::ID => "Nama Domain",
         _ => "Domain name",
     }
 }
@@ -509,7 +549,8 @@ pub fn only_show_favorites_translation(language: Language) -> &'static str {
         Language::ES => "Mostrar solo los favoritos",
         Language::KO => "즐겨찾기만 보기",
         Language::ZH => "仅显示收藏",
-        Language::UK => "Показувати лише обрані",
+        Language::ZH_TW => "僅顯示我的最愛",
+        Language::UK => "Показувати лише улюблені",
         Language::RO => "Arată doar favorite",
         Language::PL => "Pokaż tylko ulubione",
         Language::FR => "Afficher uniquement les favoris",
@@ -517,6 +558,7 @@ pub fn only_show_favorites_translation(language: Language) -> &'static str {
         Language::UZ => "Faqat sevimlilarni ko'rsatish",
         Language::PT => "Apenas mostrar os favoritos",
         Language::VI => "Chỉ hiển thị mục ưa thích",
+        Language::ID => "Hanya tunjukkan favorit",
         _ => "Only show favorites",
     }
 }
@@ -534,6 +576,7 @@ pub fn only_show_favorites_translation(language: Language) -> &'static str {
 //         Language::ES => "Filtros de búsqueda",
 //         Language::KO => "검색 필터",
 //         Language::ZH => "搜索条件",
+//         Language::ZH_TW => "搜尋篩選器",
 //         Language::UK => "Фільтри пошуку",
 //         Language::RO => "Filtre de căutare",
 //         Language::PL => "Filtry wyszukiwania",
@@ -541,6 +584,7 @@ pub fn only_show_favorites_translation(language: Language) -> &'static str {
 //         Language::JA => "検索フィルター",
 //         Language::UZ => "Qidiruv filtrlari",
 //         Language::PT => "Filtros de busca",
+//         Language::ID => "Filter Pencarian",
 //         _ => "Search filters",
 //     }
 // }
@@ -558,6 +602,7 @@ pub fn no_search_results_translation(language: Language) -> &'static str {
         Language::ES => "Los filtros de búsqueda especificados no generan ningún resultado",
         Language::KO => "해당 검색 필터로 검색된 결과가 없습니다.",
         Language::ZH => "没有符合条件的条目",
+        Language::ZH_TW => "根據指定的篩選條件，找不到任何結果",
         Language::UK => "Немає результатів згідно з обраними фільтрами пошуку",
         Language::RO => "Niciun rezultat disponibil conform filtrelor de căutare specificate",
         Language::PL => "Brak wyników zgodnych z określonymi filtrami wyszukiwania",
@@ -566,6 +611,7 @@ pub fn no_search_results_translation(language: Language) -> &'static str {
         Language::UZ => "Belgilangan qidiruv filtrlari bo'yicha hech qanday natija mavjud emas",
         Language::PT => "Nenhum resultado disponível de acordo com os filtros selecionados",
         Language::VI => "Không có kết quả nào theo các bộ lọc được chỉ định",
+        Language::ID => "Tidak ada hasil berdasarkan filter pencarian spesifik",
         _ => "No result available according to the specified search filters",
     }
 }
@@ -588,6 +634,7 @@ pub fn showing_results_translation(
         Language::ES => format!("Mostrando {start}-{end} de {total} resultados totales"),
         Language::KO => format!("총 {total}개의 결과 중 {start}-{end}을(를) 보여줍니다"),
         Language::ZH => format!("显示累计 {total} 条目中第 {start}-{end} 个"),
+        Language::ZH_TW => format!("顯示總共 {total} 個結果中的第 {start}-{end} 個"),
         Language::UK => format!("Показано {start}-{end} з {total} загальних результатів"),
         Language::RO => format!("Se afișează {start}-{end} din {total} rezultate"),
         Language::PL => format!("Wyświetlanie {start}-{end} z {total} wyników"),
@@ -596,6 +643,7 @@ pub fn showing_results_translation(
         Language::UZ => format!("Jami {total} natijadan {start}-{end} ko'rsatilyapti"),
         Language::PT => format!("Mostrando {start}-{end} de {total} resultados totais"),
         Language::VI => format!("Đang hiển thị {start}-{end} của {total} tổng số kết quả"),
+        Language::ID => format!("Menampilkan {start}-{end} dari {total} semua hasil"),
         _ => format!("Showing {start}-{end} of {total} total results"),
     }
 }
@@ -614,6 +662,7 @@ pub fn color_gradients_translation(language: Language) -> &'static str {
         Language::ES => "Aplicar gradientes de color",
         Language::KO => "그라디언트 색상 적용",
         Language::ZH => "应用渐变色",
+        Language::ZH_TW => "套用色彩漸層",
         Language::UK => "Застосувати кольорові градієнти",
         Language::RO => "Aplicați gradient de culoare",
         Language::PL => "Zastosuj gradient kolorów",
@@ -622,6 +671,7 @@ pub fn color_gradients_translation(language: Language) -> &'static str {
         Language::UZ => "Rang gradientlarini qo'llang",
         Language::PT => "Aplicar gradientes de cor",
         Language::VI => "Áp dụng color gradients",
+        Language::ID => "Aplikasikan gradasi warna",
         _ => "Apply color gradients",
     }
 }
