@@ -21,8 +21,12 @@ pub fn general_translation(language: Language) -> &'static str {
         Language::SV => "Allmänt",
         Language::VI => "Tổng quan",
         Language::ZH => "通用",
+        Language::ZH_TW => "一般",
         Language::KO => "일반",
         Language::TR => "Genel",
+        Language::PT => "Geral",
+        Language::UK => "Загальні",
+        Language::ID => "Umum",
         _ => "General",
     }
 }
@@ -35,6 +39,7 @@ pub fn zoom_translation(language: Language) -> &'static str {
         | Language::FR
         | Language::DE
         | Language::RO
+        | Language::PT
         | Language::SV => "Zoom",
         // Language::FA => "بزرگنمایی",
         Language::PL => "Powiększenie",
@@ -43,8 +48,11 @@ pub fn zoom_translation(language: Language) -> &'static str {
         Language::UZ => "Kattalashtirish",
         Language::VI => "Phóng to",
         Language::ZH => "缩放",
+        Language::ZH_TW => "縮放",
         Language::KO => "확대",
         Language::TR => "Yakınlaştırma",
+        Language::UK => "Масштабування",
+        Language::ID => "Perbesar",
         _ => "Zoom",
     }
 }
@@ -65,8 +73,12 @@ pub fn mmdb_files_translation(language: Language) -> &'static str {
         Language::SV => "Databasfiler",
         Language::VI => "Tập tin cơ sở dữ liệu",
         Language::ZH => "数据库文件",
+        Language::ZH_TW => "資料庫檔案",
         Language::KO => "데이터베이스 파일",
         Language::TR => "Veri tabanı dosyaları",
+        Language::PT => "Arquivos da base de dados",
+        Language::UK => "Файли бази даних",
+        Language::ID => "Berkas database",
         _ => "Database files",
     }
 }
@@ -87,8 +99,12 @@ pub fn params_not_editable_translation(language: Language) -> &'static str {
         Language::SV => "Följande parametrar kan inte ändras under analysen",
         Language::VI => "Các tham số sau không thể bị thay đổi khi đang phân tích",
         Language::ZH => "以下参数在分析过程中不能修改",
+        Language::ZH_TW => "以下參數在分析期間無法修改",
         Language::KO => "분석 중 다음의 매개변수들은 수정할 수 없습니다",
         Language::TR => "Analiz sırasında bu parametrelere müdahale edilemez",
+        Language::PT => "Os seguintes parâmetros não podem ser modificados durante a análise",
+        Language::UK => "Наступні параметри не можна змінювати під час аналізу трафіку",
+        Language::ID => "Parameter berikut tidak bisa diubah saat dianalisa",
         _ => "The following parameters can't be modified during the analysis",
     }
 }
@@ -97,7 +113,7 @@ pub fn custom_style_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Custom style",
         // Language::FA => "شیوه سفارشی",
-        Language::ES => "Estilo personalizado",
+        Language::ES | Language::PT => "Estilo personalizado",
         Language::IT => "Stile personalizzato",
         Language::FR => "Style personnalisé",
         Language::DE => "Benutzerdefinierter Stil",
@@ -109,8 +125,11 @@ pub fn custom_style_translation(language: Language) -> &'static str {
         Language::SV => "Anpassad stil",
         Language::VI => "Tùy chỉnh chủ đề",
         Language::ZH => "自定义样式",
+        Language::ZH_TW => "自訂佈景主題",
         Language::KO => "사용자 지정 스타일",
         Language::TR => "Kişisel görünüm",
+        Language::UK => "Власний стиль",
+        Language::ID => "Ubah Model",
         _ => "Custom style",
     }
 }
@@ -129,8 +148,12 @@ pub fn copy_translation(language: Language) -> &'static str {
         Language::SV => "Kopia",
         Language::VI => "Sao chép",
         Language::ZH => "复制",
+        Language::ZH_TW => "複製",
         Language::KO => "복사",
         Language::TR => "Kopyala",
+        Language::PT => "Copiar",
+        Language::UK => "Копіювати",
+        Language::ID => "Salin",
         _ => "Copy",
     }
 }
@@ -147,12 +170,15 @@ pub fn port_translation(language: Language) -> &'static str {
         | Language::TR => "Port",
         // Language::FA => "درگاه",
         Language::ES => "Puerto",
-        Language::IT => "Porta",
+        Language::IT | Language::PT => "Porta",
         Language::RU => "Порт",
         Language::JA => "ポート",
         Language::VI => "Cổng",
         Language::ZH => "端口",
+        Language::ZH_TW => "連接埠",
         Language::KO => "포트",
+        Language::UK => "Порт",
+        Language::ID => "Port",
         _ => "Port",
     }
 }
@@ -161,7 +187,7 @@ pub fn invalid_filters_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Invalid filters",
         // Language::FA => "صافی نامعتبر",
-        Language::ES => "Filtros inválidos",
+        Language::ES | Language::PT => "Filtros inválidos",
         Language::IT => "Filtri non validi",
         Language::FR => "Filtres invalides",
         Language::DE => "Ungültige Filter",
@@ -173,8 +199,11 @@ pub fn invalid_filters_translation(language: Language) -> &'static str {
         Language::SV => "Ogiltiga filter",
         Language::VI => "Bộ lọc không khả dụng",
         Language::ZH => "无效的过滤器",
+        Language::ZH_TW => "無效的篩選器",
         Language::KO => "잘못된 필터",
         Language::TR => "Geçersiz filtreler",
+        Language::UK => "Неправильний формат фільтрів",
+        Language::ID => "Filter salah",
         _ => "Invalid filters",
     }
 }
@@ -194,8 +223,12 @@ pub fn messages_translation(language: Language) -> &'static str {
         Language::SV => "Meddelanden",
         Language::VI => "Tin nhắn",
         Language::ZH => "信息",
+        Language::ZH_TW => "訊息",
         Language::KO => "메시지",
         Language::TR => "Mesajlar",
+        Language::PT => "Mensagens",
+        Language::UK => "Повідомлення",
+        Language::ID => "Pesan",
         _ => "Messages",
     }
 }
@@ -216,8 +249,12 @@ pub fn link_type_translation(language: Language) -> &'static str {
         Language::SV => "Länktyp",
         Language::VI => "Loại liên kết",
         Language::ZH => "链接类型",
+        Language::ZH_TW => "連線類型",
         Language::KO => "링크 유형",
         Language::TR => "Link türü",
+        Language::PT => "Tipo de conexão",
+        Language::UK => "Різновид зʼєднання",
+        Language::ID => "Tipe koneksi",
         _ => "Link type",
     }
 }
@@ -227,22 +264,54 @@ pub fn unsupported_link_type_translation<'a>(
     adapter: &str,
 ) -> Text<'a, StyleType> {
     let translation = match language {
-        Language::EN => "The link type associated with this adapter is not supported by Sniffnet yet...",
+        Language::EN => {
+            "The link type associated with this adapter is not supported by Sniffnet yet..."
+        }
         // Language::FA => "نوع پیوند مرتبط با این مبدل هنوز توسط Sniffnet پشتیبانی نمی شود...",
-        Language::ES => "La conexión asociada con este adaptador aún no esta implementada en Sniffnet...",
-        Language::IT => "Il tipo di collegamento associato a questo adattatore di rete non è ancora supportato da Sniffnet...",
-        Language::FR => "Le type de connexion associé à cet adaptateur n'est pas encore supporté par Sniffnet...",
-        Language::DE => "Die Verbindungsart dieses Adapters wird noch nicht von Sniffnet unterstützt...",
-        Language::PL => "Rodzaj połączenia powiązany z tym adapterem nie jest jeszcze obsługiwany przez Sniffnet...",
-        Language::RU => "Тип соединения, связанный с этим адаптером, пока не поддерживается Sniffnet...",
-        Language::RO => "Tipul conexiunii asociate acestui adaptor de rețea nu este încă suportat de Sniffnet...",
-        Language::JA => "このアダプターのリンク タイプは Sniffnet ではまだサポートされていません...",
-        Language::UZ => "Ushbu adapter bilan bog'langan havola turi hozircha Sniffnet tomonidan qo'llab quvvatlanmaydi...",
+        Language::ES => {
+            "La conexión asociada a este adaptador aún no está soportada por Sniffnet..."
+        }
+        Language::IT => {
+            "Il tipo di collegamento associato a questo adattatore di rete non è ancora supportato da Sniffnet..."
+        }
+        Language::FR => {
+            "Le type de connexion associé à cet adaptateur n'est pas encore supporté par Sniffnet..."
+        }
+        Language::DE => {
+            "Die Verbindungsart dieses Adapters wird noch nicht von Sniffnet unterstützt..."
+        }
+        Language::PL => {
+            "Rodzaj połączenia powiązany z tym adapterem nie jest jeszcze obsługiwany przez Sniffnet..."
+        }
+        Language::RU => {
+            "Тип соединения, связанный с этим адаптером, пока не поддерживается Sniffnet..."
+        }
+        Language::RO => {
+            "Tipul conexiunii asociate acestui adaptor de rețea nu este încă suportat de Sniffnet..."
+        }
+        Language::JA => {
+            "このアダプターのリンク タイプは Sniffnet ではまだサポートされていません..."
+        }
+        Language::UZ => {
+            "Ushbu adapter bilan bog'langan havola turi hozircha Sniffnet tomonidan qo'llab quvvatlanmaydi..."
+        }
         Language::SV => "Länktypen associerad med denna adapter stöds inte av Sniffnet än...",
         Language::VI => "Loại liên kết được gắn với adapter này chưa được Sniffnet hỗ trợ...",
         Language::ZH => "Sniffnet 尚不支持与此适配器关联的链接类型...",
+        Language::ZH_TW => "Sniffnet 目前尚不支援與此網路介面卡相關的連線類型...",
         Language::KO => "이 어댑터와 연결된 링크 유형은 Sniffnet에서 아직 지원되지 않습니다...",
-        Language::TR => "Bu adaptör ile ilişkilendirilmiş link türü henüz Sniffnet tarafından desteklenmiyor...",
+        Language::TR => {
+            "Bu adaptör ile ilişkilendirilmiş link türü henüz Sniffnet tarafından desteklenmiyor..."
+        }
+        Language::PT => {
+            "O tipo de conexão associado com este adaptador não é suportado pelo Sniffnet ainda..."
+        }
+        Language::UK => {
+            "Різновид зʼєднання, повʼязаний з даним адаптером, ще не підтримується Sniffnet-ом..."
+        }
+        Language::ID => {
+            "Tipe koneksi yang terhubung dengan adaptor ini belum didukung oleh Sniffnet"
+        }
         _ => "The link type associated with this adapter is not supported by Sniffnet yet...",
     };
 
@@ -268,8 +337,12 @@ pub fn style_from_file_translation(language: Language) -> &'static str {
         Language::SV => "Välj stil från en fil",
         Language::VI => "Chọn chủ đề từ file của bạn",
         Language::ZH => "从文件中选择样式",
+        Language::ZH_TW => "從檔案中選擇佈景主題",
         Language::KO => "파일에서 스타일을 선택하세요",
         Language::TR => "Dosyadan bir görünüm seç",
+        Language::PT => "Selecionar estilo a partir de um arquivo",
+        Language::UK => "Виберіть стиль з файлу",
+        Language::ID => "Pilih model / gaya dari berkas",
         _ => "Select style from a file",
     }
 }
@@ -290,8 +363,12 @@ pub fn database_from_file_translation(language: Language) -> &'static str {
         Language::SV => "Välj databasfil",
         Language::VI => "Chọn tập tin cơ sở dữ liệu",
         Language::ZH => "选择数据库文件",
+        Language::ZH_TW => "選擇資料庫檔案",
         Language::KO => "데이터베이스 파일 선택",
         Language::TR => "Veri tabanı dosyası seç",
+        Language::PT => "Selecione um arquivo de base de dados",
+        Language::UK => "Виберіть файл бази даних",
+        Language::ID => "Pilih berkas database",
         _ => "Select database file",
     }
 }
@@ -312,8 +389,12 @@ pub fn filter_by_host_translation(language: Language) -> &'static str {
         Language::SV => "Filtrera efter nätverksvärd",
         Language::VI => "Lọc bởi máy chủ mạng",
         Language::ZH => "按网络主机筛选",
+        Language::ZH_TW => "依網路主機篩選",
         Language::KO => "네트워크 호스트로 필터링",
         Language::TR => "Ağ sunucusuna göre filtrele",
+        Language::PT => "Filtrar por host de rede",
+        Language::UK => "Фільтр за хостом мережі",
+        Language::ID => "Filter berdasarkan jaringan asal",
         _ => "Filter by network host",
     }
 }
@@ -331,8 +412,12 @@ pub fn service_translation(language: Language) -> &'static str {
         Language::UZ => "Xizmat",
         Language::VI => "Dịch vụ",
         Language::ZH => "服务",
+        Language::ZH_TW => "服務",
         Language::KO => "서비스",
         Language::TR => "Servis",
+        Language::PT => "Serviço",
+        Language::UK => "Сервіс",
+        Language::ID => "Layanan",
         _ => "Service",
     }
 }
@@ -352,8 +437,13 @@ pub fn export_capture_translation(language: Language) -> &'static str {
         Language::SV => "Exportera inspelningsfil",
         Language::VI => "Xuất tập tin đã bắt",
         Language::ZH => "导出捕获文件",
+        Language::ZH_TW => "匯出擷取的檔案",
         Language::KO => "캡처 파일 내보내기",
         Language::TR => "Yakalanan dosyayı dışa aktar",
+        Language::PT => "Exportar arquivo capturado",
+        Language::UK => "Експорт файлу захоплення",
+        Language::ID => "Ekspor data tangkapan",
+        Language::ES => "Exportar archivo de captura",
         _ => "Export capture file",
     }
 }
@@ -372,8 +462,13 @@ pub fn directory_translation(language: Language) -> &'static str {
         Language::JA => "ディレクトリー",
         Language::VI => "Thư mục",
         Language::ZH => "目录",
+        Language::ZH_TW => "目錄",
         Language::KO => "디렉토리",
         Language::TR => "Klasör",
+        Language::PT => "Diretório",
+        Language::UK => "Тека",
+        Language::ID => "Direktori",
+        Language::ES => "Directorio",
         _ => "Directory",
     }
 }
@@ -393,8 +488,13 @@ pub fn select_directory_translation(language: Language) -> &'static str {
         Language::SV => "Välj målkatalog",
         Language::VI => "Chọn thư mục đích đến",
         Language::ZH => "选择目标目录",
+        Language::ZH_TW => "選擇目的目錄",
         Language::KO => "대상 디렉토리 선택",
         Language::TR => "Hedef klasörü seç",
+        Language::PT => "Selecionar diretório de destino",
+        Language::UK => "Виберіть теку призначення",
+        Language::ID => "Pilih direktori tujuan",
+        Language::ES => "Selecciona el directorio de destino",
         _ => "Select destination directory",
     }
 }
@@ -414,8 +514,13 @@ pub fn file_name_translation(language: Language) -> &'static str {
         Language::SV => "Filnamn",
         Language::VI => "Tên file",
         Language::ZH => "文件名",
+        Language::ZH_TW => "檔案名稱",
         Language::KO => "파일 이름",
         Language::TR => "Dosya adı",
+        Language::PT => "Nome do arquivo",
+        Language::UK => "Назва файлу",
+        Language::ID => "Nama berkas",
+        Language::ES => "Nombre del archivo",
         _ => "File name",
     }
 }
@@ -435,29 +540,38 @@ pub fn thumbnail_mode_translation(language: Language) -> &'static str {
         Language::SV => "Miniatyrläge",
         Language::VI => "Chế độ thu nhỏ",
         Language::ZH => "缩略图模式",
+        Language::ZH_TW => "縮圖模式",
         Language::KO => "썸네일 모드",
         Language::TR => "Küçük resim modu",
+        Language::PT | Language::ES => "Modo miniatura",
+        Language::UK => "Режим мініатюри",
+        Language::ID => "Mode gambar kecil",
         _ => "Thumbnail mode",
     }
 }
 
-pub fn learn_more_translation(language: Language) -> &'static str {
-    match language {
-        Language::EN => "Do you want to learn more?",
-        // Language::FA => "آیا می خواهید بیشتر یاد بگیرید؟",
-        Language::IT => "Vuoi saperne di più?",
-        Language::FR => "Voulez-vous en savoir davantage?",
-        Language::DE => "Mehr erfahren",
-        Language::PL => "Chcesz dowiedzieć się więcej?",
-        Language::RU => "Хотите узнать больше?",
-        Language::RO => "Vrei să înveți mai multe?",
-        Language::JA => "もっと知りたいですか？",
-        Language::UZ => "Ko'proq bilishni hohlaysizmi?",
-        Language::SV => "Vill du veta mer?",
-        Language::VI => "Bạn có muốn tìm hiểu thêm?",
-        Language::ZH => "想知道更多吗？",
-        Language::KO => "더 자세히 알고 싶으십니까?",
-        Language::TR => "Daha fazlasını öğrenmek ister misin?",
-        _ => "Do you want to learn more?",
-    }
-}
+// pub fn learn_more_translation(language: Language) -> &'static str {
+//     match language {
+//         Language::EN => "Do you want to learn more?",
+//         // Language::FA => "آیا می خواهید بیشتر یاد بگیرید؟",
+//         Language::IT => "Vuoi saperne di più?",
+//         Language::FR => "Voulez-vous en savoir davantage?",
+//         Language::DE => "Mehr erfahren",
+//         Language::PL => "Chcesz dowiedzieć się więcej?",
+//         Language::RU => "Хотите узнать больше?",
+//         Language::RO => "Vrei să înveți mai multe?",
+//         Language::JA => "もっと知りたいですか？",
+//         Language::UZ => "Ko'proq bilishni hohlaysizmi?",
+//         Language::SV => "Vill du veta mer?",
+//         Language::VI => "Bạn có muốn tìm hiểu thêm?",
+//         Language::ZH => "想知道更多吗？",
+//         Language::ZH_TW => "想了解更多嗎？",
+//         Language::KO => "더 자세히 알고 싶으십니까?",
+//         Language::TR => "Daha fazlasını öğrenmek ister misin?",
+//         Language::PT => "Quer aprender mais?",
+//         Language::UK => "Бажаєте дізнатись більше?",
+//         Language::ID => "Apakah kamu mau belajar lebih lanjut?",
+//         Language::ES => "¿Quieres aprender más?",
+//         _ => "Do you want to learn more?",
+//     }
+// }
